==> kde4games_3.80.3.orig.tar.gz: kdegames-3.80.3/kbackgammon/kbgtextview.h <==
/* Yo Emacs, this -*- C++ -*-

  Copyright (C) 1999,2000 Jens Hoefkens
  jens@hoefkens.com

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

*/

#ifndef __KBGTEXTVIEW_H
#define __KBGTEXTVIEW_H

#include <ktextbrowser.h>
#include <QString>


/**
 * A small extension to the QTextView control.
 */
class KBgTextView : public KTextBrowser
{
	Q_OBJECT

public:

	/**
	 * Constructor
	 */
	KBgTextView(QWidget *parent = 0, const char *name = 0);

	/**
	 * Destructor
	 */
	virtual ~KBgTextView();

public slots:

	/**
	 * Restore previously saved setting or provides defaults
	 */
        void readConfig();

	/**
	 * Save current settings
	 */
	void saveConfig();

        /**
	 * Simple interface to the non-slot function selectFont()
	 */
        void selectFont();
	/**
	 * Write the string at the end of the buffer and scroll to
	 * the end
	 */
	void write(const QString &);
};

#endif // __KBGTEXTVIEW_H

==> kde4games_3.94.0.orig.tar.gz: kdegames-3.94.0/kbackgammon/kbgtextview.h <==
/* Yo Emacs, this -*- C++ -*-

  Copyright (C) 1999,2000 Jens Hoefkens
  jens@hoefkens.com

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

*/

#ifndef __KBGTEXTVIEW_H
#define __KBGTEXTVIEW_H

#include <ktextbrowser.h>



/**
 * A small extension to the QTextView control.
 */
class KBgTextView : public KTextBrowser
{
	Q_OBJECT

public:

	/**
	 * Constructor
	 */
	explicit KBgTextView(QWidget *parent = 0);

	/**
	 * Destructor
	 */
	virtual ~KBgTextView();

public slots:

	/**
	 * Restore previously saved setting or provides defaults
	 */
        void readConfig();

	/**
	 * Save current settings
	 */
	void saveConfig();

        /**
	 * Simple interface to the non-slot function selectFont()
	 */
        void selectFont();
	/**
	 * Write the string at the end of the buffer and scroll to
	 * the end
	 */
	void write(const QString &);
};

#endif // __KBGTEXTVIEW_H
